.. _all-salt.returners:

==============================
Full list of builtin returners
==============================

.. currentmodule:: salt.returners

.. autosummary::
    :toctree:
    :template: autosummary.rst.tmpl

    local
    cassandra_return
    mongo_return
    redis_return
